@@ -1,10 +1,14 @@
 package Image::Magick::Square;
-use Image::Magick;
 use Carp;
-
+use vars qw($VERSION);
 use strict;
 use warnings;
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.3 $ =~ /(\d+)/g;
+
+
+sub import {
+   *{Image::Magick::Trim2Square} = \&create;
+}
 
 
 # Image Magick Square
@@ -49,26 +53,35 @@ sub create {
 
 __END__
 
+=pod
+
 =head1 NAME
 
-Image::Magick::Square - Takes image and crops to a square
+Image::Magick::Square - Takes image and crops trims to a square shape
 
 =head1 SYNOPSIS
 
-	use Image::Magick::Square;
-	
-	# Load your source image
+   use Image::Magick;
+	use Image::Magick::Square;	
+
+   # instance and read in image
 	my $src = new Image::Magick;
 	$src->Read('source.jpg');
 
-	# crop to square image
-	my $square_thumb = Image::Magick::Square::create($thumb);
+   # square it
+	my $square = Image::Magick::Square::create($src);
 
 	# Save it 
-	$square_thumb->Write('square.jpg');
+	$square->Write('square.jpg');
 
-=cut
 
+   use Image::Magick;
+   use Image::Magick::Square;
+
+   my $i = new Image::Magick;
+   $i->Read('./my.jpg');
+   $i->Trim2Square;
+   $i->Write('./squared.jpg');
 
 =head1 EXAMPLE
 
@@ -80,7 +93,7 @@ To make a square thumbnail:
 	my $src = new Image::Magick;
 	$src->Read('source.jpg');
 
-	# make into a thumbnail
+	# resize it down some..
 	my ($thumb,$x,$y) = Image::Magick::Thumbnail::create($src,50);
 
 	# crop to biggest square that will fit inside image.
@@ -89,11 +102,10 @@ To make a square thumbnail:
 	# Save it 
 	$square_thumb->Write('square_thumb.jpg');
 
-=cut	
 
 =head1 DESCRIPTION
 
-The subroutine C<create> takes as argument an ImageMagick image object.
+The subroutine create() takes as argument an ImageMagick image object.
 
 It returns an ImageMagick image object (the thumbnail), as well as the
 number of pixels of the I<side> of the image.
@@ -102,18 +114,31 @@ It does not take dimension arguments, because if your image is cropped
 according to the dimensions it already posseses.
 
 This module is useful if you want to make square thumbnails. You should
-first make the thumbnail, and then call C<create>, so as to use less of
+first make the thumbnail, and then call create(), so as to use less of
 the computer's resources. 
 
 You can run this conversion on any image magick object. 
 
-=cut
+The subroutine is not exported.
+
+A method is aliased onto Image::Magick::Trim2Square
+
+=head1 SUBS
+
+=head2 Image::Magick::Square::create()
+
+Argument is Image::Magick object.
+Trims top and bottom or sides as needed to make it into a square shape.
+Returns object.
+
+=head2 Trim2Square()
+
+Is an alias for Image::Magick::Square::create(), it is placed inside the 
+Image::Magick namespace. 
 
 =head1 PREREQUISITES
 
-C<Image::Magick>
-
-=cut
+L<Image::Magick>
 
 =head2 NOTES
 
@@ -122,7 +147,8 @@ It's great, I love it. Except for one thing, it does not take an existing
 Image::Magick object to work on. It does too much.  It doesn't return an
 image object either.
 
-Image::Magick::Square is more a specialized crop then a "thumbnail routine".
+Image::Magick::Square is more a specialized crop then a 
+"thumbnail subroutine".
 This way, you can add more effects, like a shadow, a border, annotate- etc, 
 I<before> you save or display the image.
 
@@ -130,7 +156,19 @@ I<before> you save or display the image.
 
 =head2 EXPORT
 
-None by default.
+This basically adds a new method to Image::Magick.
+
+   use Image::Magick;
+   use Image::Magick::Square;
+   
+   my $i = new Image::Magick;
+   $i->Read('./my.jpg');
+   $i->Trim2Square;
+
+If you wish to avoid importing Trim2Square onto the Image::Magick namespace..
+
+   use Image::Magick::Square();
+
 
 =head1 SEE ALSO
 
@@ -139,11 +177,11 @@ L<Image::Magick::Thumbnail>, L<Image::Magick::Thumbnail::Fixed>.
 
 =head1 AUTHOR
 
-Leo Charre, E<lt>leo@leocharre.comE<gt>
+Leo Charre leocharre at cpan dot org
 
 =head1 COPYRIGHT
 
-Copyright (C) Leo Charre 2006 all rights reserved.
+Copyright (C) Leo Charre 2006-2008 all rights reserved.
 Available under the same terms as Perl itself.
 
 =cut
